# AICafe

This is a Python package for intracranial vascular image analysis.
See more in the documentation.

This package is currently not ready to be used. Current version is only used as a placeholder.
